@@ -83,6 +83,8 @@ class BaseTemplate(template.PageTemplate):
 
     strict = False
 
+    trim_attribute_space = True
+
     @property
     def boolean_attributes(self):
         if self.content_type == 'text/xml':
@@ -115,20 +117,18 @@ class BaseTemplate(template.PageTemplate):
         request = context.setdefault('request', None)
 
         if target_language is None:
-            if hasattr(request, "get"):
-                target_language = request.get("LANGUAGE", None)
-            if target_language is None:
-                try:
-                    target_language = i18n.negotiate(request)
-                except:
-                    target_language = None
+            try:
+                target_language = i18n.negotiate(request)
+            except:
+                target_language = None
 
         context['target_language'] = target_language
 
         # bind translation-method to request
         def translate(
             msgid, domain=None, mapping=None,
-            target_language=None, default=None):
+            target_language=None, default=None,
+            context=None):
             if msgid is MV:
                 # Special case handling of Zope2's Missing.MV
                 # (Missing.Value) used by the ZCatalog but is
